- [ ] Update documentation

  - [ ] Shorter README

    - what is it
    - how it looks
    - how to install and run
    - where to find documentation
    - where to report bugs
    - where to find source code

  - [ ] Newer screenshots
  - [ ] Create a man page with rst2man

- [ ] Fix icon in .desktop file for the Debian package

- [ ] Release 0.9.0 to PyPI and the Ubuntu PPA

- [ ] 'Edit config file' menu entry

- [ ] Weekly summary in the main GUI window (or sidebar)

- [ ] Keep all the data in memory please

- [ ] Python 3 port

- [ ] I18n

- [ ] Usability:

  - [ ] Internal reporting
  - [ ] Preferences dialog

